```
Usage: vcd vapp deploy [OPTIONS] NAME [VM_NAMES]...

Options:
  --power-on / --power-off  Specifies whether to power on/off vApp/VM on
                            deployment,if not specified, default is power on
  --force-customization     Specifies whether to force customization on
                            deployment,if not specified, default is False
  -h, --help                Show this message and exit.

```
